pub struct ServiceAttributeStore {
pub crate_name: &'static str,
pub pkg_name: &'static str,
pub version: &'static str,
pub version_major: &'static str,
pub version_minor: &'static str,
pub version_patch: &'static str,
}Expand description
Compile-time attributes to be provided by the owning application/service.
Used as a set of parameters to pass to init()
Service attributes can be generated and passed in using the build_attrs macro, e.g.:
use tracing_kickstart::TracingConfig;
let attrs = tracing_kickstart::build_attrs!();
let conf = TracingConfig::default();
let custom_fallback_env_filter = None;
let extra_resource_attrs = None;
let tracing_providers = tracing_kickstart::init(attrs, &conf, custom_fallback_env_filter, extra_resource_attrs).unwrap();Fields
crate_name: &'static strpkg_name: &'static strversion: &'static strversion_major: &'static strversion_minor: &'static strversion_patch: &'static strImplementations