pub struct TracingConfigBuilder { /* private fields */ }Implementations
Sourceimpl TracingConfigBuilder
impl TracingConfigBuilder
pub fn new(runtime_config: &TracingConfigOverride) -> Self
pub fn build(self) -> TracingConfig
Sourcepub fn log_file_path(self, path: Option<String>) -> Self
pub fn log_file_path(self, path: Option<String>) -> Self
Enables file logging at given path, if provided
Sourcepub fn ansi_output(self, val: bool) -> Self
pub fn ansi_output(self, val: bool) -> Self
enables ANSI (color) output in tracing-subscriber
Default value: true
Sourcepub fn ansi_sanitization(self, val: bool) -> Self
pub fn ansi_sanitization(self, val: bool) -> Self
enables ANSI sanitization in tracing-subscriber
Default value: true
Sourcepub fn filter(self, filter: Option<String>) -> Self
pub fn filter(self, filter: Option<String>) -> Self
Custom env filter which takes priority over RUST_LOG, if provided
This is useful for providing a sane default for logging
It’s recommended to use [TracingOverrideConfig::filter_append] to make adjustments at runtime.
Sourcepub fn metrics_interval(self, interval: Option<u64>) -> Self
pub fn metrics_interval(self, interval: Option<u64>) -> Self
If provided, will configure the metrics export period (duration in seconds)
Sourcepub fn custom_resource_attrs(self, attrs: Option<Vec<(Key, Value)>>) -> Self
pub fn custom_resource_attrs(self, attrs: Option<Vec<(Key, Value)>>) -> Self
Custom OTEL resource attributes
Can only be set using the TracingConfigBuilder